@@ -112,21 +112,22 @@ class JenkinsData:
             logging.info('skipping build: %s %s', project_name, build_number)
             return
 
-        if artifact:
-            asyncio.run(self.pull_artifact(json_file, overwrite=overwrite))
-        if recursive_upstream:
-            cause = upstream_lookup(json_file)
-            if cause:
-                self.pull(
-                    project_name=cause['upstreamProject'],
-                    build_number=cause['upstreamBuild'],
-                    recursive_upstream=recursive_upstream,
-                    artifact=artifact,
-                    overwrite=overwrite,
-                    recursive_previous=0,
-                    recursive_previous_trial=recursive_previous_trial,
-                    continue_when_exist=True
-                )
+        if os.path.exists(json_file):
+            if artifact:
+                asyncio.run(self.pull_artifact(json_file, overwrite=overwrite))
+            if recursive_upstream:
+                cause = upstream_lookup(json_file)
+                if cause:
+                    self.pull(
+                        project_name=cause['upstreamProject'],
+                        build_number=cause['upstreamBuild'],
+                        recursive_upstream=recursive_upstream,
+                        artifact=artifact,
+                        overwrite=overwrite,
+                        recursive_previous=0,
+                        recursive_previous_trial=recursive_previous_trial,
+                        continue_when_exist=True
+                    )
         if recursive_previous:
             previous_build = build_number - 1
             _trial = self.skip_trial if os.path.exists(json_file) else recursive_previous_trial
